@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 use etwin_cli::cmd::dump;
 
 #[tokio::main]
