@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 use etwin_config::Config;
 use etwin_core::types::AnyError;
 use std::env;
@@ -9,7 +9,7 @@ use std::path::{Path, PathBuf};
 use tokio::process::Command;
 
 /// Arguments to the `dump` task.
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub struct DumpArgs {
   /// Output directory
   ///
