@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 use dialoguer::{theme::ColorfulTheme, Input};
 use etwin_core::clock::SystemClock;
 use etwin_core::oauth::RfcOauthAccessTokenKey;
@@ -8,7 +8,7 @@ use etwin_core::types::AnyError;
 use etwin_twinoid_client::http::HttpTwinoidClient;
 
 /// Arguments to the `twinoid` task.
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub struct TwinoidArgs {}
 
 pub async fn run(_args: &TwinoidArgs) -> Result<(), AnyError> {
