@@ -1,5 +1,5 @@
 use crate::rest::RestArgs;
-use clap::Clap;
+use clap::Parser;
 use etwin_core::types::AnyError;
 
 pub mod cmd {
@@ -9,14 +9,14 @@ pub mod cmd {
 }
 pub mod rest;
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(author = "Eternaltwin")]
 pub struct CliArgs {
   #[clap(subcommand)]
   command: CliCommand,
 }
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub enum CliCommand {
   /// Run the Dinoparc client demo
   #[clap(name = "dinoparc")]
