@@ -1,6 +1,6 @@
-use chrono::{TimeZone, Utc};
-use clap::Clap;
+use clap::Parser;
 use etwin_core::clock::VirtualClock;
+use etwin_core::core::Instant;
 use etwin_core::dinoparc::DinoparcStore;
 use etwin_core::hammerfest::{HammerfestClient, HammerfestStore};
 use etwin_core::link::LinkStore;
@@ -19,11 +19,11 @@ use std::net::{SocketAddr, SocketAddrV6};
 use std::sync::Arc;
 
 /// Arguments to the `rest` task.
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub struct RestArgs {}
 
 fn create_api() -> RouterApi {
-  let clock = Arc::new(VirtualClock::new(Utc.ymd(2020, 1, 1).and_hms(0, 0, 0)));
+  let clock = Arc::new(VirtualClock::new(Instant::ymd_hms(2020, 1, 1, 0, 0, 0)));
   let hammerfest_client: Arc<dyn HammerfestClient> = Arc::new(HttpHammerfestClient::new(Arc::clone(&clock)).unwrap());
   let hammerfest_store: Arc<dyn HammerfestStore> = Arc::new(MemHammerfestStore::new(Arc::clone(&clock)));
   let dinoparc_store: Arc<dyn DinoparcStore> = Arc::new(MemDinoparcStore::new(Arc::clone(&clock)));
